#ifndef PREFERENCES_H
#define PREFERENCES_H

#include <sstream>
#include <string>
#include <QIODevice>

namespace Harbinger {

    /**
     * This class encapsulates all the preferences available to the
     * user through the <c>PreferencesDialog</c> class.  This class is
     * also responsible for serializing and deserializing itself so
     * the preferences can be saved to a file.
     */
    class Preferences {
    public:

        /**
         * Default constructor.
         */
        Preferences();

        /**
         * Serialize this instance to the output stream <c>ostrm</c>.
         * If an error occurs, an exception is throw.
         *
         * @param[in] ostrm output stream
         */
        void
        serialize(QIODevice& ostrm) const;

        /**
         * Deserialize this instance from the input stream
         * <c>istrm</c>.  If an error occurs, an exception is thrown.
         *
         * @param[in] istrm input stream
         */
        static Preferences
        deserialize(QIODevice& istrm);

        /**
         * The amount of idle time (in seconds) before advance notice
         * is given to the user that the screensaver is about to be
         * enabled.
         */
        unsigned long advanceNotice;

        /**
         * The amount of idle time (in seconds) before the screensaver
         * is enabled.
         */
        unsigned long screensaver;

        /**
         * The message to display when advance notice is given.
         */
        std::string message;

    };

}

#endif  /*  PREFERENCES_H  */
